@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -10,19 +10,19 @@
 #include "texttospeechlanguagecombobox.h"
 #include <KLocalizedString>
 
-#include <QFormLayout>
-#include <QSlider>
-#include <QComboBox>
-#include <QTimer>
 #include <KConfig>
 #include <KConfigGroup>
+#include <QComboBox>
+#include <QFormLayout>
+#include <QSlider>
+#include <QTimer>
 
 using namespace KPIMTextEdit;
 TextToSpeechConfigWidget::TextToSpeechConfigWidget(QWidget *parent)
     : QWidget(parent)
     , mAbstractTextToSpeechConfigInterface(new TextToSpeechConfigInterface(this))
 {
-    auto *layout = new QFormLayout(this);
+    auto layout = new QFormLayout(this);
     mVolume = new QSlider(this);
     mVolume->setObjectName(QStringLiteral("volume"));
     mVolume->setRange(0, 100);
@@ -130,7 +130,7 @@ void TextToSpeechConfigWidget::restoreDefaults()
     mPitch->setValue(0);
     mVolume->setValue(50);
 
-    //TODO
+    // TODO
 }
 
 void TextToSpeechConfigWidget::updateAvailableEngine()
@@ -195,5 +195,5 @@ void TextToSpeechConfigWidget::slotEngineChanged()
 
 void TextToSpeechConfigWidget::slotLanguageChanged()
 {
-    //QLocale locale = mLanguage->currentData().value<QLocale>();
+    // QLocale locale = mLanguage->currentData().value<QLocale>();
 }
